﻿using System;
using Ozeki.VoIP;

namespace Message_Waiting_Indication
{
    class Program
    {
        static ISoftPhone softphone;
        static IPhoneLine phoneLine;
        static ISIPSubscription mwiSubscription;

        static void Main(string[] args)
        {
            // Create a softphone object with RTP port range 5000-10000
            softphone = SoftPhoneFactory.CreateSoftPhone(5000, 10000);

            // SIP account registration data, (supplied by your VoIP service provider)
            var registrationRequired = true;
            var userName = "sipusername";
            var displayName = "sipdisplayname";
            var authenticationId = "authenticationid";
            var registerPassword = "Password";
            var domainHost = "pbxip.voipprovider.com";
            var domainPort = 5060;

            var account = new SIPAccount(registrationRequired, displayName, userName, authenticationId, registerPassword, domainHost, domainPort);

            // Send SIP regitration request
            RegisterAccount(account);

            // Prevents the termination of the application
            Console.ReadLine();
        }

        static void RegisterAccount(SIPAccount account)
        {
            try
            {
                phoneLine = softphone.CreatePhoneLine(account);
                phoneLine.RegistrationStateChanged += sipAccount_RegStateChanged;
                softphone.RegisterPhoneLine(phoneLine);
            }
            catch (Exception ex)
            {
                Console.WriteLine("Error during SIP registration: " + ex);
            }
        }

        private static void sipAccount_RegStateChanged(object sender, RegistrationStateChangedArgs e)
        {
            if (e.State == RegState.Error || e.State == RegState.NotRegistered)
                Console.WriteLine("Registration failed!");

            if (e.State == RegState.RegistrationSucceeded)
            {
                Console.WriteLine("Registration succeeded - Online!");

                mwiSubscription = phoneLine.Subscription.Create(SIPEventType.MessageSummary);
                mwiSubscription.NotificationReceived += subscription_NotificationReceived;
                phoneLine.Subscription.Subscribe(mwiSubscription);
            }
        }

        static void subscription_NotificationReceived(object sender, SIPEventNotificationArgs e)
        {
            Console.WriteLine("Message-summary received. Message waiting: " + e.MessageSummary.MessageWaiting);
        }
    }
}
